@@ -17,12 +17,15 @@
  */
 
 /*
- * $Id: auth.c,v 1.2.2.3 2001/01/23 05:55:40 maxk Exp $
+ * auth.c,v 1.2.2.7.2.3 2006/11/16 04:02:33 mtbishop Exp
  */ 
 
 /*
  * Challenge based authentication. 
- * Thanx to Chris Todd<christ@insynq.com> for the good idea.   
+ * Thanx to Chris Todd<christ@insynq.com> for the good idea.
+ *
+ * Jim Yonan, 05/24/2001
+ * 	gen_chal rewrite to use better random number generator 
  */ 
 
 #include "config.h"
@@ -58,8 +61,14 @@
 /* Encryption and Decryption of the challenge key */
 #ifdef HAVE_SSL
 
-#include <md5.h>
-#include <blowfish.h>
+#include <openssl/md5.h>
+#include <openssl/blowfish.h>
+#include <openssl/rand.h>
+
+void gen_chal(char *buf)
+{
+   RAND_bytes(buf, VTUN_CHAL_SIZE);
+}
 
 void encrypt_chal(char *chal, char *pwd)
 { 
@@ -99,10 +108,7 @@ void inline decrypt_chal(char *chal, char *pwd)
    encrypt_chal(chal, pwd);
 }
 
-#endif /* HAVE_SSL */
-
-/* Generate PSEUDO random challenge key. 
- * FIXME. Should be rewritten to use better algorithm */
+/* Generate PSEUDO random challenge key. */
 void gen_chal(char *buf)
 {
    register int i;
@@ -112,6 +118,7 @@ void gen_chal(char *buf)
    for(i=0; i < VTUN_CHAL_SIZE; i++)
       buf[i] = (unsigned int)(255.0 * rand()/RAND_MAX);
 }
+#endif /* HAVE_SSL */
 
 /* 
  * Functions to convert binary flags to character string.
@@ -166,7 +173,7 @@ char *bf2cf(struct vtun_host *host)
 	*(ptr++) = 'K';
 
      if( host->flags & VTUN_ENCRYPT )
-	*(ptr++) = 'E';
+	ptr += sprintf(ptr,"E%d", host->cipher);
 
      strcat(ptr,">");
 
@@ -222,7 +229,11 @@ int cf2bf(char *str, struct vtun_host *host)
 		ptr = p;
 		break;
 	     case 'E':
+		if((s = strtol(ptr,&p,10)) == ERANGE || ptr == p) 
+		   return 0;
 		host->flags |= VTUN_ENCRYPT;
+		host->cipher = s; 
+		ptr = p;
 		break;
      	     case 'S':
 		if((s = strtol(ptr,&p,10)) == ERANGE || ptr == p) 
@@ -268,7 +279,7 @@ char *cl2cs(char *chal)
 
 int cs2cl(char *str, char *chal)
 {
-     register unsigned char *ptr = str;
+     register char *ptr = str;
      register int i;
 
      if( !(ptr = strchr(str,'<')) ) 
