@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: lfd_lzo.c,v 1.1.1.2.2.5 2001/01/23 05:55:40 maxk Exp $
+ * lfd_lzo.c,v 1.1.1.2.2.7.2.1 2006/11/16 04:03:00 mtbishop Exp
  */ 
 
 /* LZO compression module */
@@ -67,19 +67,19 @@ int alloc_lzo(struct vtun_host *host)
      }
 
      if( lzo_init() != LZO_E_OK ){
-	syslog(LOG_ERR,"Can't initialize compressor");
+	vtun_syslog(LOG_ERR,"Can't initialize compressor");
 	return 1;
      }	
      if( !(zbuf = lfd_alloc(zbuf_size)) ){
-	syslog(LOG_ERR,"Can't allocate buffer for the compressor");
+	vtun_syslog(LOG_ERR,"Can't allocate buffer for the compressor");
 	return 1;
      }	
      if( !(wmem = lzo_malloc(mem)) ){
-	syslog(LOG_ERR,"Can't allocate buffer for the compressor");
+	vtun_syslog(LOG_ERR,"Can't allocate buffer for the compressor");
 	return 1;
      }	
 
-     syslog(LOG_INFO, "LZO compression[level %d] initialized", zlevel);
+     vtun_syslog(LOG_INFO, "LZO compression[level %d] initialized", zlevel);
 
      return 0;
 }
@@ -102,29 +102,29 @@ int free_lzo()
  */  
 int comp_lzo(int len, char *in, char **out)
 { 
-     int zlen = 0;    
+     unsigned int zlen = 0;    
      int err;
      
-     if( (err=lzo1x_compress(in,len,zbuf,&zlen,wmem)) != LZO_E_OK ){
-        syslog(LOG_ERR,"Compress error %d",err);
+     if( (err=lzo1x_compress((void *)in,len,zbuf,&zlen,wmem)) != LZO_E_OK ){
+        vtun_syslog(LOG_ERR,"Compress error %d",err);
         return -1;
      }
 
-     *out = zbuf;
+     *out = (void *)zbuf;
      return zlen;
 }
 
 int decomp_lzo(int len, char *in, char **out)
 {
-     int zlen = 0;     
+     unsigned int zlen = 0;
      int err;
 
-     if( (err=lzo1x_decompress(in,len,zbuf,&zlen,wmem)) != LZO_E_OK ){
-        syslog(LOG_ERR,"Decompress error %d",err);
+     if( (err=lzo1x_decompress((void *)in,len,zbuf,&zlen,wmem)) != LZO_E_OK ){
+        vtun_syslog(LOG_ERR,"Decompress error %d",err);
         return -1;
      }
 
-     *out = zbuf;
+     *out = (void *) zbuf;
      return zlen;
 }
 
@@ -144,7 +144,7 @@ struct lfd_mod lfd_lzo = {
 
 int no_lzo(struct vtun_host *host)
 {
-     syslog(LOG_INFO, "LZO compression is not supported");
+     vtun_syslog(LOG_INFO, "LZO compression is not supported");
      return -1;
 }
 
