@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: lfd_zlib.c,v 1.1.1.2.2.4 2001/01/23 05:55:40 maxk Exp $
+ * lfd_zlib.c,v 1.1.1.2.2.6.2.1 2006/11/16 04:03:14 mtbishop Exp
  */ 
 
 /* ZLIB compression module */
@@ -38,7 +38,7 @@
 #include <zlib.h>
 
 static z_stream zi, zd; 
-static char *zbuf;
+static unsigned char *zbuf;
 static int zbuf_size = VTUN_FRAME_SIZE + 200;
 
 /* 
@@ -57,19 +57,19 @@ int zlib_alloc(struct vtun_host *host)
      zi.opaque = (voidpf)0;
     
      if( deflateInit(&zd, zlevel ) != Z_OK ){
-	syslog(LOG_ERR,"Can't initialize compressor");
+	vtun_syslog(LOG_ERR,"Can't initialize compressor");
 	return 1;
      }	
      if( inflateInit(&zi) != Z_OK ){
-	syslog(LOG_ERR,"Can't initialize decompressor");
+	vtun_syslog(LOG_ERR,"Can't initialize decompressor");
 	return 1;
      }	
-     if( !(zbuf = lfd_alloc(zbuf_size)) ){
-	syslog(LOG_ERR,"Can't allocate buffer for the compressor");
+     if( !(zbuf = (void *) lfd_alloc(zbuf_size)) ){
+	vtun_syslog(LOG_ERR,"Can't allocate buffer for the compressor");
 	return 1;
      }
    
-     syslog(LOG_INFO,"ZLIB compression[level %d] initialized.", zlevel);
+     vtun_syslog(LOG_INFO,"ZLIB compression[level %d] initialized.", zlevel);
      return 0;
 }
 
@@ -109,15 +109,15 @@ int zlib_comp(int len, char *in, char **out)
      int oavail, olen = 0;    
      int err;
  
-     zd.next_in = in;
+     zd.next_in = (void *) in;
      zd.avail_in = len;
-     zd.next_out = zbuf;
+     zd.next_out = (void *) zbuf;
      zd.avail_out = zbuf_size;
     
      while(1) {
         oavail = zd.avail_out;
         if( (err=deflate(&zd, Z_SYNC_FLUSH)) != Z_OK ){
-           syslog(LOG_ERR,"Deflate error %d",err);
+           vtun_syslog(LOG_ERR,"Deflate error %d",err);
            return -1;
         }
         olen += oavail - zd.avail_out;
@@ -125,11 +125,11 @@ int zlib_comp(int len, char *in, char **out)
 	   break;
 
         if( expand_zbuf(&zd,100) ) {
-	   syslog( LOG_ERR, "Can't expand compression buffer");
+	   vtun_syslog( LOG_ERR, "Can't expand compression buffer");
            return -1;
 	}
      }
-     *out = zbuf;
+     *out = (void *) zbuf;
      return olen;
 }
 
@@ -138,26 +138,26 @@ int zlib_decomp(int len, char *in, char **out)
      int oavail = 0, olen = 0;     
      int err;
 
-     zi.next_in = in;
+     zi.next_in = (void *) in;
      zi.avail_in = len;
-     zi.next_out = zbuf;
+     zi.next_out = (void *) zbuf;
      zi.avail_out = zbuf_size;
 
      while(1) {
         oavail = zi.avail_out;
         if( (err=inflate(&zi, Z_SYNC_FLUSH)) != Z_OK ) {
-           syslog(LOG_ERR,"Inflate error %d len %d", err, len);
+           vtun_syslog(LOG_ERR,"Inflate error %d len %d", err, len);
            return -1;
         }
         olen += oavail - zi.avail_out;
         if(!zi.avail_in)
 	   break;
         if( expand_zbuf(&zi,100) ) {
-	   syslog( LOG_ERR, "Can't expand compression buffer");
+	   vtun_syslog( LOG_ERR, "Can't expand compression buffer");
            return -1;
 	}
      }
-     *out = zbuf;
+     *out = (void *) zbuf;
      return olen;
 }
 
@@ -177,7 +177,7 @@ struct lfd_mod lfd_zlib = {
 
 int no_zlib(struct vtun_host *host)
 {
-     syslog(LOG_INFO, "ZLIB compression is not supported");
+     vtun_syslog(LOG_INFO, "ZLIB compression is not supported");
      return -1;
 }
 
