@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: lib.c,v 1.1.1.2.2.2 2000/09/21 01:08:53 maxk Exp $
+ * lib.c,v 1.1.1.2.2.9.2.1 2006/11/16 04:03:17 mtbishop Exp
  */ 
 
 #include "config.h"
@@ -39,6 +39,8 @@
 #include "linkfd.h"
 #include "lib.h"
 
+volatile sig_atomic_t __io_canceled = 0;
+
 #ifndef HAVE_SETPROC_TITLE
 /* Functions to manipulate with program title */
 
@@ -284,13 +286,13 @@ int run_cmd(void *d, void *opt)
 	case 0:
 	   break;
 	case -1:
-	   syslog(LOG_ERR,"Couldn't fork()");
+	   vtun_syslog(LOG_ERR,"Couldn't fork()");
 	   return 0;
 	default:
     	   if( cmd->flags & VTUN_CMD_WAIT ){
 	      /* Wait for termination */
 	      if( waitpid(pid,&st,0) > 0 && (WIFEXITED(st) && WEXITSTATUS(st)) )
-		 syslog(LOG_INFO,"Command [%s %.20s] error %d", 
+		 vtun_syslog(LOG_INFO,"Command [%s %.20s] error %d", 
 				cmd->prog ? cmd->prog : "sh",
 				cmd->args ? cmd->args : "", 
 				WEXITSTATUS(st) );
@@ -319,7 +321,7 @@ int run_cmd(void *d, void *opt)
      }
      execv(cmd->prog, argv);
 
-     syslog(LOG_ERR,"Couldn't exec program %s", cmd->prog);
+     vtun_syslog(LOG_ERR,"Couldn't exec program %s", cmd->prog);
      exit(1);
 }
 
@@ -339,4 +341,22 @@ void free_sopt( struct vtun_sopt *opt )
 	free(opt->raddr);
         opt->raddr = NULL;
      }
-};
+}
+
+void vtun_syslog (int priority, char *format, ...)
+{
+   static volatile sig_atomic_t in_syslog= 0;
+   char buf[255];
+   va_list ap;
+
+   if(! in_syslog) {
+      in_syslog = 1;
+    
+      va_start(ap, format);
+      vsnprintf(buf, sizeof(buf)-1, format, ap);
+      syslog(priority, "%s", buf);
+      va_end(ap);
+
+      in_syslog = 0;
+   }
+}
