@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: netlib.c,v 1.7.2.3 2000/09/21 18:40:26 maxk Exp $
+ * netlib.c,v 1.7.2.4.2.2 2006/11/16 04:03:47 mtbishop Exp
  */ 
 
 #include "config.h"
@@ -149,7 +149,7 @@ int udp_session(struct vtun_host *host)
      int s,opt;
 
      if( (s=socket(AF_INET,SOCK_DGRAM,0))== -1 ){
-        syslog(LOG_ERR,"Can't create socket");
+        vtun_syslog(LOG_ERR,"Can't create socket");
         return -1;
      }
 
@@ -159,39 +159,39 @@ int udp_session(struct vtun_host *host)
      /* Set local address and port */
      local_addr(&saddr, host, 1);
      if( bind(s,(struct sockaddr *)&saddr,sizeof(saddr)) ){
-        syslog(LOG_ERR,"Can't bind to the socket");
+        vtun_syslog(LOG_ERR,"Can't bind to the socket");
         return -1;
      }
 
      opt = sizeof(saddr);
      if( getsockname(s,(struct sockaddr *)&saddr,&opt) ){
-        syslog(LOG_ERR,"Can't get socket name");
+        vtun_syslog(LOG_ERR,"Can't get socket name");
         return -1;
      }
 
      /* Write port of the new UDP socket */
      port = saddr.sin_port;
      if( write_n(host->rmt_fd,(char *)&port,sizeof(short)) < 0 ){
-        syslog(LOG_ERR,"Can't write port number");
+        vtun_syslog(LOG_ERR,"Can't write port number");
         return -1;
      }
      host->sopt.lport = htons(port);
 
      /* Read port of the other's end UDP socket */
      if( readn_t(host->rmt_fd,&port,sizeof(short),host->timeout) < 0 ){
-        syslog(LOG_ERR,"Can't read port number %s", strerror(errno));
+        vtun_syslog(LOG_ERR,"Can't read port number %s", strerror(errno));
         return -1;
      }
 
      opt = sizeof(saddr);
      if( getpeername(host->rmt_fd,(struct sockaddr *)&saddr,&opt) ){
-        syslog(LOG_ERR,"Can't get peer name");
+        vtun_syslog(LOG_ERR,"Can't get peer name");
         return -1;
      }
 
      saddr.sin_port = port;
      if( connect(s,(struct sockaddr *)&saddr,sizeof(saddr)) ){
-        syslog(LOG_ERR,"Can't connect socket");
+        vtun_syslog(LOG_ERR,"Can't connect socket");
         return -1;
      }
      host->sopt.rport = htons(port);
@@ -200,49 +200,26 @@ int udp_session(struct vtun_host *host)
      close(host->rmt_fd); 
      host->rmt_fd = s;	
 
-     syslog(LOG_INFO,"UDP connection initialized");
+     vtun_syslog(LOG_INFO,"UDP connection initialized");
      return s;
 }
 
 /* Set local address */
 int local_addr(struct sockaddr_in *addr, struct vtun_host *host, int con)
 {
-     struct hostent * hent;
      int opt;
 
      if( con ){
         /* Use address of the already connected socket. */
         opt = sizeof(struct sockaddr_in);
         if( getsockname(host->rmt_fd, (struct sockaddr *)addr, &opt) < 0 ){
-           syslog(LOG_ERR,"Can't get local socket address");
+           vtun_syslog(LOG_ERR,"Can't get local socket address");
            return -1; 
         }
      } else {
-        memset(addr, 0, sizeof(struct sockaddr_in));
-        addr->sin_family = AF_INET;
-        switch( host->src_addr.type ){
-           case VTUN_ADDR_IFACE:
-              if( !( addr->sin_addr.s_addr = getifaddr(host->src_addr.name)) ){
-                 syslog(LOG_ERR,"Can't get address of interface %s", 
-					host->src_addr.name);
+        if (generic_addr(addr, &host->src_addr) < 0)
                  return -1;
               }
-	      break;
-           case VTUN_ADDR_NAME:
-              if( !(hent = gethostbyname(host->src_addr.name)) ){
-                 syslog(LOG_ERR,"Can't resolv local address %s", 
-					host->src_addr.name);
-                 return -1;
-              }
-              addr->sin_addr.s_addr = *(unsigned long *)hent->h_addr; 
-	      break;
-           default:
-              addr->sin_addr.s_addr = INADDR_ANY; 
-              break;
-        }
-     }
-     if( host->src_addr.port )	
-        addr->sin_port = htons(host->src_addr.port);
 
      host->sopt.laddr = strdup(inet_ntoa(addr->sin_addr));
 
@@ -255,20 +232,58 @@ int server_addr(struct sockaddr_in *addr, struct vtun_host *host)
 
      memset(addr,0,sizeof(struct sockaddr_in));
      addr->sin_family = AF_INET;
-     addr->sin_port = htons(vtun.svr_port);
+     addr->sin_port = htons(vtun.bind_addr.port);
 
      /* Lookup server's IP address.
       * We do it on every reconnect because server's IP 
       * address can be dynamic.
       */
      if( !(hent = gethostbyname(vtun.svr_name)) ){
-        syslog(LOG_ERR, "Can't resolv server address: %s", vtun.svr_name);
+        vtun_syslog(LOG_ERR, "Can't resolv server address: %s", vtun.svr_name);
         return -1;
      }
      addr->sin_addr.s_addr = *(unsigned long *)hent->h_addr; 
 
      host->sopt.raddr = strdup(inet_ntoa(addr->sin_addr));
-     host->sopt.rport = vtun.svr_port;
+     host->sopt.rport = vtun.bind_addr.port;
+
+     return 0; 
+}
+
+/* Set address by interface name, ip address or hostname */
+int generic_addr(struct sockaddr_in *addr, struct vtun_addr *vaddr)
+{
+     struct hostent *hent;
+     memset(addr, 0, sizeof(struct sockaddr_in));
+  
+     addr->sin_family = AF_INET;
+  
+     switch (vaddr->type) {
+        case VTUN_ADDR_IFACE:
+	 if (!(addr->sin_addr.s_addr =
+	       getifaddr(vaddr->name))) {
+	    vtun_syslog(LOG_ERR,
+	                "Can't get address of interface %s",
+	                vaddr->name);
+	    return -1;
+	 }
+           break;
+        case VTUN_ADDR_NAME:
+	 if (!(hent = gethostbyname(vaddr->name))) {
+	    vtun_syslog(LOG_ERR,
+	                "Can't resolv local address %s",
+	                vaddr->name);
+	    return -1;
+           }
+	 addr->sin_addr.s_addr = *(unsigned long *) hent->h_addr;
+           break;
+        default:
+           addr->sin_addr.s_addr = INADDR_ANY;
+           break;
+     }
+  
+     if (vaddr->port)
+        addr->sin_port = htons(vaddr->port);
 
      return 0; 
 }
